==> kdemultimedia-3.2.3.tar.bz2: kdemultimedia-3.2.3/libkcddb/submit.h <==
/*
  Copyright (C) 2002 Rik Hemsley (rikkus) <rik@kde.org>
  Copyright (C) 2002 Benjamin Meyer <ben-devel@meyerhome.net>
  Copyright (C) 2002 Nadeem Hasan <nhasan@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#ifndef KCDDB_SUBMIT_H
#define KCDDB_SUBMIT_H

#include "cddb.h"
#include "cdinfo.h"

namespace KCDDB
{
  class Submit : public CDDB
  {
    public:

      enum Transport
      {
        None,
        SMTP,
        HTTP
      };

      Submit();
      virtual ~Submit();

      virtual Result submit(const CDInfo &, const TrackOffsetList &) = 0;
      QString validCategory(const QString&);

    protected:

      Result parseWrite( const QString & );
      void makeDiskData( const CDInfo&, const TrackOffsetList& );
      QString diskData_;
  };
}

#endif // KCDDB_SUBMIT_H
// vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1

==> kdemultimedia-3.3.2.tar.bz2: kdemultimedia-3.3.2/libkcddb/submit.h <==
/*
  Copyright (C) 2002 Rik Hemsley (rikkus) <rik@kde.org>
  Copyright (C) 2002 Benjamin Meyer <ben-devel@meyerhome.net>
  Copyright (C) 2002 Nadeem Hasan <nhasan@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#ifndef KCDDB_SUBMIT_H
#define KCDDB_SUBMIT_H

#include "cddb.h"
#include "cdinfo.h"

namespace KCDDB
{
  class Submit : public CDDB
  {
    public:

      enum Transport
      {
        None,
        SMTP,
        HTTP
      };

      Submit();
      virtual ~Submit();

      virtual Result submit(const CDInfo &, const TrackOffsetList &) = 0;
      bool validCategory(const QString&);

    protected:

      Result parseWrite( const QString & );
      void makeDiskData( const CDInfo&, const TrackOffsetList& );
      QString diskData_;
  };
}

#endif // KCDDB_SUBMIT_H
// vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
